==> rWikiPathways_1.6.1.zip: rWikiPathways/doc/rWikiPathways-and-BridgeDbR.R <==
## ---- echo = FALSE------------------------------------------------------------
knitr::opts_chunk$set(
  eval=FALSE
)

## -----------------------------------------------------------------------------
#  if(!"rWikiPathways" %in% installed.packages()){
#      if (!requireNamespace("BiocManager", quietly=TRUE))
#          install.packages("BiocManager")
#      BiocManager::install("rWikiPathways")
#  }
#  library(rWikiPathways)
#  if(!"BridgeDbR" %in% installed.packages()){
#      if (!requireNamespace("BiocManager", quietly=TRUE))
#          install.packages("BiocManager")
#      BiocManager::install("BridgeDbR")
#  }
#  library(BridgeDbR)

## -----------------------------------------------------------------------------
#      orgNames <- listOrganisms()
#      orgNames

## -----------------------------------------------------------------------------
#      unlist(lapply(orgNames,BridgeDbR::getOrganismCode))

## -----------------------------------------------------------------------------
#      BridgeDbR::getSystemCode("Ensembl")

## -----------------------------------------------------------------------------
#      BridgeDbR::getSystemCode("Entrez Gene")

## -----------------------------------------------------------------------------
#      tnf.pathways <- findPathwayIdsByXref('TNF', getSystemCode('HGNC'))
#      tnf.pathways

## -----------------------------------------------------------------------------
#      getXrefList('WP554', getSystemCode('Ensembl'))

## -----------------------------------------------------------------------------
#      getXrefList('WP554', getSystemCode('ChEBI'))

## -----------------------------------------------------------------------------
#      BridgeDbR::getFullName('Ce')

==> rWikiPathways_1.7.3.zip: rWikiPathways/doc/rWikiPathways-and-BridgeDbR.R <==
## ---- echo = FALSE------------------------------------------------------------
knitr::opts_chunk$set(
  eval=FALSE
)

## -----------------------------------------------------------------------------
#  if(!"rWikiPathways" %in% installed.packages()){
#      if (!requireNamespace("BiocManager", quietly=TRUE))
#          install.packages("BiocManager")
#      BiocManager::install("rWikiPathways")
#  }
#  library(rWikiPathways)
#  if(!"BridgeDbR" %in% installed.packages()){
#      if (!requireNamespace("BiocManager", quietly=TRUE))
#          install.packages("BiocManager")
#      BiocManager::install("BridgeDbR")
#  }
#  library(BridgeDbR)

## -----------------------------------------------------------------------------
#      orgNames <- listOrganisms()
#      orgNames

## -----------------------------------------------------------------------------
#      BridgeDbR::getOrganismCode(orgNames[1])

## -----------------------------------------------------------------------------
#      BridgeDbR::getSystemCode("Ensembl")

## -----------------------------------------------------------------------------
#      BridgeDbR::getSystemCode("Entrez Gene")

## -----------------------------------------------------------------------------
#      tnf.pathways <- findPathwayIdsByXref('TNF', getSystemCode('HGNC'))
#      tnf.pathways

## -----------------------------------------------------------------------------
#      getXrefList('WP554', getSystemCode('Ensembl'))

## -----------------------------------------------------------------------------
#      getXrefList('WP554', getSystemCode('ChEBI'))

## -----------------------------------------------------------------------------
#      BridgeDbR::getFullName('Ce')
